@@ -1,18 +1,18 @@
 /*
  * Copyright (c) 2011 Red Hat, Inc.
  *
- * Gnome Documents is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by 
+ * the Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
  *
- * Gnome Documents is distributed in the hope that it will be useful, but
+ * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * for more details.
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public 
+ * License for more details.
  *
- * You should have received a copy of the GNU General Public License along
- * with Gnome Documents; if not, write to the Free Software Foundation,
+ * You should have received a copy of the GNU Lesser General Public License 
+ * along with this program; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  * Author: Cosimo Cecchi <cosimoc@redhat.com>
@@ -173,6 +173,7 @@ gd_main_toolbar_constructed (GObject *obj)
   grid = gtk_grid_new ();
   gtk_widget_set_halign (grid, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (grid, GTK_ALIGN_CENTER);
+  gtk_grid_set_column_spacing (GTK_GRID (grid), 12);
   gtk_container_add (GTK_CONTAINER (self->priv->center_group), grid);
 
   self->priv->title_label = gtk_label_new (NULL);
@@ -181,7 +182,6 @@ gd_main_toolbar_constructed (GObject *obj)
 
   self->priv->detail_label = gtk_label_new (NULL);
   gtk_widget_set_no_show_all (self->priv->detail_label, TRUE);
-  gtk_widget_set_margin_left (self->priv->detail_label, 12);
   gtk_style_context_add_class (gtk_widget_get_style_context (self->priv->detail_label), "dim-label");
   gtk_container_add (GTK_CONTAINER (grid), self->priv->detail_label);
 
