@@ -1,18 +1,18 @@
 /*
  * Copyright (c) 2011 Red Hat, Inc.
  *
- * Gnome Documents is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by 
+ * the Free Software Foundation; either version 2 of the License, or (at your
  * option) any later version.
  *
- * Gnome Documents is distributed in the hope that it will be useful, but
+ * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * for more details.
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public 
+ * License for more details.
  *
- * You should have received a copy of the GNU General Public License along
- * with Gnome Documents; if not, write to the Free Software Foundation,
+ * You should have received a copy of the GNU Lesser General Public License 
+ * along with this program; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  * Author: Cosimo Cecchi <cosimoc@redhat.com>
@@ -35,8 +35,7 @@ struct _GdMainViewPrivate {
   GtkWidget *current_view;
   GtkTreeModel *model;
 
-  gdouble button_press_x;
-  gdouble button_press_y;
+  gchar *button_press_item_path;
 };
 
 enum {
@@ -68,6 +67,16 @@ gd_main_view_dispose (GObject *obj)
   G_OBJECT_CLASS (gd_main_view_parent_class)->dispose (obj);
 }
 
+static void
+gd_main_view_finalize (GObject *obj)
+{
+  GdMainView *self = GD_MAIN_VIEW (obj);
+
+  g_free (self->priv->button_press_item_path);
+
+  G_OBJECT_CLASS (gd_main_view_parent_class)->finalize (obj);
+}
+
 static void
 gd_main_view_init (GdMainView *self)
 {
@@ -147,6 +156,7 @@ gd_main_view_class_init (GdMainViewClass *klass)
   oclass->get_property = gd_main_view_get_property;
   oclass->set_property = gd_main_view_set_property;
   oclass->dispose = gd_main_view_dispose;
+  oclass->finalize = gd_main_view_finalize;
 
   properties[PROP_VIEW_TYPE] =
     g_param_spec_int ("view-type",
@@ -368,6 +378,7 @@ on_button_release_event (GtkWidget *view,
   GdMainView *self = user_data;
   GdMainViewGeneric *generic = get_generic (self);
   GtkTreePath *path;
+  gchar *button_release_item_path;
   gboolean entered_mode = FALSE, selection_mode;
   gboolean res, same_item = FALSE;
 
@@ -379,12 +390,15 @@ on_button_release_event (GtkWidget *view,
 
   if (path != NULL)
     {
-      if (event->x == self->priv->button_press_x &&
-          event->y == self->priv->button_press_y)
+      button_release_item_path = gtk_tree_path_to_string (path);
+      if (g_strcmp0 (self->priv->button_press_item_path, button_release_item_path) == 0)
         same_item = TRUE;
+
+      g_free (button_release_item_path);
     }
 
-  self->priv->button_press_x = self->priv->button_press_y = 0;
+  g_free (self->priv->button_press_item_path);
+  self->priv->button_press_item_path = NULL;
 
   if (!same_item)
     {
@@ -426,21 +440,11 @@ on_button_press_event (GtkWidget *view,
   GList *selection, *l;
   GtkTreePath *sel_path;
   gboolean found = FALSE;
-  gdouble event_x = 0, event_y = 0;
-
-  self->priv->button_press_x = event->x;
-  self->priv->button_press_y = event->y;
 
   path = gd_main_view_generic_get_path_at_pos (generic, event->x, event->y);
 
   if (path != NULL)
-    {
-      event_x = event->x;
-      event_y = event->y;
-    }
-
-  self->priv->button_press_x = event_x;
-  self->priv->button_press_y = event_y;
+    self->priv->button_press_item_path = gtk_tree_path_to_string (path);
 
   if (!self->priv->selection_mode ||
       path == NULL)
@@ -476,18 +480,15 @@ on_drag_begin (GdMainViewGeneric *generic,
                gpointer user_data)
 {
   GdMainView *self = user_data;
-  GtkTreePath *path;
 
-  path = gd_main_view_generic_get_path_at_pos (generic,
-                                               self->priv->button_press_x,
-                                               self->priv->button_press_y);
-
-  if (path != NULL)
+  if (self->priv->button_press_item_path != NULL)
     {
       gboolean res;
       GtkTreeIter iter;
       GdkPixbuf *icon = NULL;
+      GtkTreePath *path;
 
+      path = gtk_tree_path_new_from_string (self->priv->button_press_item_path);
       res = gtk_tree_model_get_iter (self->priv->model,
                                      &iter, path);
       if (res)
@@ -538,8 +539,6 @@ clear_selection_list_foreach (GtkTreeModel *model,
                               GtkTreeIter *iter,
                               gpointer user_data)
 {
-  gboolean is_selected;
-
   gtk_list_store_set (GTK_LIST_STORE (model), iter,
                       GD_MAIN_COLUMN_SELECTED, FALSE,
                       -1);
