@@ -127,25 +127,20 @@ BaseManager.prototype = {
         return retval;
     },
 
+    forEachItem: function(func) {
+        for (idx in this._items)
+            func(this._items[idx]);
+    },
+
     _getAllFilter: function() {
-        let filter = '';
-        let first = true;
+        let filters = [];
 
-        for (idx in this._items) {
-            let item = this._items[idx];
+        this.forEachItem(function(item) {
+            if (item.id != 'all')
+                filters.push(item.getFilter());
+        });
 
-            if (item.id == 'all')
-                continue;
-
-            if (first)
-                first = false;
-            else
-                filter += ' || ';
-
-            filter += item.getFilter();
-        }
-
-        return '(' + filter + ')';
+        return '(' + filters.join(' || ') + ')';
     },
 
     processNewItems: function(newItems) {
@@ -231,13 +226,14 @@ BaseView.prototype = {
         this._treeView.set_model(this._model.model);
 
         let selection = this._treeView.get_selection();
-        selection.set_mode(Gtk.SelectionMode.SINGLE);
+        selection.set_mode(Gtk.SelectionMode.NONE);
 
         this._treeView.connect('row-activated', Lang.bind(this,
             function(view, path) {
                 let iter = this._model.model.get_iter(path)[1];
                 let id = this._model.model.get_value(iter, BaseModelColumns.ID);
 
+                this.emit('item-activated');
                 this._manager.setActiveItemById(id);
             }));
 
@@ -291,3 +287,4 @@ BaseView.prototype = {
             additionalFunc(col, cell, model, iter);
     }
 };
+Signals.addSignalMethods(BaseView.prototype);
