@@ -344,21 +344,24 @@ OrganizeCollectionModel.prototype = {
     },
 
     _findCollectionIter: function(item) {
-        let retval = null;
+        let collPath = null;
 
         this.model.foreach(Lang.bind(this,
             function(model, path, iter) {
                 let id = model.get_value(iter, OrganizeModelColumns.ID);
 
                 if (item.id == id) {
-                    retval = iter;
+                    collPath = path.copy();
                     return true;
                 }
 
                 return false;
             }));
 
-        return retval;
+        if (collPath)
+            return this.model.get_iter(collPath)[1];
+
+        return null;
     },
 
     _onFetchCollectionStateForSelection: function(collectionState) {
@@ -366,18 +369,17 @@ OrganizeCollectionModel.prototype = {
 
         for (idx in collectionState) {
             let item = Global.collectionManager.getItemById(idx);
-            let iter = null;
 
             if ((collectionState[item.id] & OrganizeCollectionState.HIDDEN) != 0)
                 continue;
 
-            iter = this._findCollectionIter(item);
+            let iter = this._findCollectionIter(item);
+
             if (!iter)
                 iter = this.model.append();
 
-            if (iter)
-                Gd.organize_store_set(this.model, iter,
-                                      item.id, item.name, collectionState[item.id]);
+            Gd.organize_store_set(this.model, iter,
+                                  item.id, item.name, collectionState[item.id]);
         }
     },
 
@@ -428,11 +430,15 @@ OrganizeCollectionModel.prototype = {
         }
     },
 
-    forgetPlaceholder: function() {
-        let path = this._placeholderRef.get_path();
-        this._placeholderRef = null;
+    getPlaceholder: function(forget) {
+        let ret = null;
 
-        return path;
+        if (this._placeholderRef)
+            ret = this._placeholderRef.get_path();
+        if (forget)
+            this._placeholderRef = null;
+
+        return ret;
     },
 
     destroy: function() {
@@ -454,6 +460,8 @@ function OrganizeCollectionView() {
 
 OrganizeCollectionView.prototype = {
     _init: function() {
+        this._choiceConfirmed = false;
+
         this._model = new OrganizeCollectionModel();
         this.widget = new Gtk.TreeView({ headers_visible: false,
                                          vexpand: true,
@@ -513,7 +521,7 @@ OrganizeCollectionView.prototype = {
             return;
         }
 
-        let path = this._model.forgetPlaceholder();
+        let path = this._model.getPlaceholder(true);
         if (!path)
             return;
 
@@ -524,7 +532,7 @@ OrganizeCollectionView.prototype = {
         job.run(null);
     },
 
-    _onTextEdited: function(cell, pathStr, newText) {
+    _onTextEditedReal: function(cell, path, newText) {
         cell.editable = false;
 
         if (!newText || newText == '') {
@@ -534,17 +542,30 @@ OrganizeCollectionView.prototype = {
         }
 
         // update the new name immediately
-        let path = Gtk.TreePath.new_from_string(pathStr);
         let iter = this._model.model.get_iter(path)[1];
         this._model.model.set_value(iter, OrganizeModelColumns.NAME, newText);
 
         // actually create the new collection
         let job = new CreateCollectionJob(newText);
-        job.run(Lang.bind(this, this._onNewCollectionCreated, path));
+        job.run(Lang.bind(this, this._onNewCollectionCreated));
     },
 
-    _onTextEditCanceled: function() {
-        this._model.removePlaceholder();
+    _onTextEdited: function(cell, pathStr, newText) {
+        this._onTextEditedReal(cell, Gtk.TreePath.new_from_string(pathStr), newText);
+    },
+
+    _onTextEditCanceled: function(cell) {
+        if (this._choiceConfirmed) {
+            this._choiceConfirmed = false;
+
+            let entry = this._viewCol.cell_area.get_edit_widget();
+            let path = this._model.getPlaceholder(false);
+
+            if (entry && path)
+                this._onTextEditedReal(cell, path, entry.get_text());
+        } else {
+            this._model.removePlaceholder();
+        }
     },
 
     _checkCellFunc: function(col, cell, model, iter) {
@@ -577,6 +598,10 @@ OrganizeCollectionView.prototype = {
 
         this._rendererText.editable = true;
         this.widget.set_cursor_on_cell(path, this._viewCol, this._rendererText, true);
+    },
+
+    confirmedChoice: function() {
+        this._choiceConfirmed = true;
     }
 };
 
@@ -597,7 +622,7 @@ OrganizeCollectionDialog.prototype = {
                                        default_height: 250 });
 
         this.widget.add_button('gtk-add', OrganizeCollectionDialogResponse.ADD);
-        this.widget.add_button('gtk-ok', Gtk.ResponseType.OK);
+        let okButton = this.widget.add_button('gtk-ok', Gtk.ResponseType.OK);
         this.widget.set_default_response(Gtk.ResponseType.OK);
 
         let contentArea = this.widget.get_content_area();
@@ -610,6 +635,20 @@ OrganizeCollectionDialog.prototype = {
         sw.add(collView.widget);
         contentArea.add(sw);
 
+        // HACK:
+        // - We want clicking on "OK" to add the typed-in collection if we're editing.
+        // - Unfortunately, since we focus out of the editable entry in order to
+        //   click the button, we'll get an editing-canceled signal on the renderer
+        //   from GTK. As this handler will run before focus-out, we here signal the
+        //   view to ignore the next editing-canceled signal and add the collection in
+        //   that case instead.
+        //
+        okButton.connect('button-press-event', Lang.bind(this,
+            function() {
+                collView.confirmedChoice();
+                return false;
+            }));
+
         this.widget.connect('response', Lang.bind(this,
             function(widget, response) {
                 if (response == OrganizeCollectionDialogResponse.ADD)
@@ -708,7 +747,6 @@ SelectionToolbar.prototype = {
         this._leftBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
         this._leftGroup = new Gtk.ToolItem({ child: this._leftBox });
         this.widget.insert(this._leftGroup, -1);
-        this._leftGroup.show_all();
 
         this._toolbarFavorite = new Gtk.ToggleButton({ child: new Gtk.Image ({ icon_name: 'emblem-favorite-symbolic',
                                                                                pixel_size: 32 })});
@@ -728,7 +766,6 @@ SelectionToolbar.prototype = {
         this._rightBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
         this._rightGroup = new Gtk.ToolItem({ child: this._rightBox });
         this.widget.insert(this._rightGroup, -1);
-        this._rightGroup.show_all();
 
         this._toolbarCollection = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'list-add-symbolic',
                                                                            pixel_size: 32 })});
@@ -748,7 +785,7 @@ SelectionToolbar.prototype = {
         this._rightBox.add(this._toolbarOpen);
         this._toolbarOpen.connect('clicked', Lang.bind(this, this._onToolbarOpen));
 
-        this.widget.show();
+        this.widget.show_all();
 
         Global.selectionController.connect('selection-mode-changed',
                                            Lang.bind(this, this._onSelectionModeChanged));
@@ -797,8 +834,9 @@ SelectionToolbar.prototype = {
         let apps = [];
         let favCount = 0;
         let showFavorite = true;
-        let canTrash = true;
-        let showPrint = false;
+        let showTrash = true;
+        let showPrint = true;
+        let showOpen = true;
 
         this._insideRefresh = true;
 
@@ -814,27 +852,15 @@ SelectionToolbar.prototype = {
                     (apps.indexOf(doc.defaultAppName) == -1))
                     apps.push(doc.defaultAppName);
 
-                if (!doc.canTrash())
-                    canTrash = false;
+                showTrash &= doc.canTrash();
+                showPrint &= !doc.collection;
             }));
 
         showFavorite &= ((favCount == 0) || (favCount == selection.length));
+        showOpen = (apps.length > 0);
 
-        if (selection.length == 1) {
-            let urn = selection[0];
-            if (!Global.collectionManager.getItemById(urn))
-                showPrint = true;
-        }
-
-        if (showPrint)
-            this._toolbarPrint.show_all();
-        else
-            this._toolbarPrint.hide();
-
-        if (canTrash)
-            this._toolbarTrash.show_all();
-        else
-            this._toolbarTrash.hide();
+        if (selection.length > 1)
+            showPrint = false;
 
         let openLabel = null;
         if (apps.length == 1) {
@@ -844,11 +870,7 @@ SelectionToolbar.prototype = {
             // Translators: this is the Open action in a context menu
             openLabel = _("Open");
         }
-
-        if (apps.length > 0) {
-            this._toolbarOpen.set_tooltip_text(openLabel);
-            this._toolbarOpen.show_all();
-        }
+        this._toolbarOpen.set_tooltip_text(openLabel);
 
         if (showFavorite) {
             let isFavorite = (favCount == selection.length);
@@ -866,11 +888,13 @@ SelectionToolbar.prototype = {
 
             this._toolbarFavorite.reset_style();
             this._toolbarFavorite.set_tooltip_text(favoriteLabel);
-            this._toolbarFavorite.show_all();
-        } else {
-            this._toolbarFavorite.hide();
         }
 
+        this._toolbarPrint.set_visible(showPrint);
+        this._toolbarTrash.set_visible(showTrash);
+        this._toolbarOpen.set_visible(showOpen);
+        this._toolbarFavorite.set_visible(showFavorite);
+
         this._insideRefresh = false;
     },
 
