@@ -19,12 +19,9 @@
  *
  */
 
-const DBus = imports.dbus;
 const Lang = imports.lang;
-const Mainloop = imports.mainloop;
 const Signals = imports.signals;
 
-const GDataMiner = imports.gDataMiner;
 const Global = imports.global;
 const Query = imports.query;
 const Utils = imports.utils;
@@ -32,8 +29,6 @@ const Utils = imports.utils;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 
-const MINER_REFRESH_TIMEOUT = 60; /* seconds */
-
 const QueryType = {
     SELECT: 0,
     UPDATE: 1,
@@ -124,9 +119,7 @@ TrackerController.prototype = {
         this._queryQueued = false;
         this._queryQueuedFlags = RefreshFlags.NONE;
         this._querying = false;
-        // startup a refresh of the gdocs cache
-        this._miner = new GDataMiner.GDataMiner();
-        this._refreshMinerNow();
+        this._isStarted = false;
 
         // useful for debugging
         this._lastQueryTime = 0;
@@ -152,24 +145,6 @@ TrackerController.prototype = {
 
         Global.searchMatchManager.connect('active-changed',
                                           Lang.bind(this, this._onSearchMatchChanged));
-
-        // perform initial query
-        this._refreshInternal(RefreshFlags.NONE);
-    },
-
-    _refreshMinerNow: function() {
-        this._miner.RefreshDBRemote(DBus.CALL_FLAG_START, Lang.bind(this,
-            function(res, error) {
-                if (error) {
-                    log('Error updating the GData cache: ' + error.toString());
-                    return;
-                }
-
-                Mainloop.timeout_add_seconds(MINER_REFRESH_TIMEOUT,
-                                             Lang.bind(this, this._refreshMinerNow));
-            }));
-
-        return false;
     },
 
     _setQueryStatus: function(status) {
@@ -197,6 +172,8 @@ TrackerController.prototype = {
 
         if (exception)
             Global.errorHandler.addQueryError(exception);
+        else
+            this._offsetController.resetItemCount();
 
         if (this._queryQueued) {
             this._queryQueued = false;
@@ -247,6 +224,8 @@ TrackerController.prototype = {
     },
 
     _refreshInternal: function(flags) {
+        this._isStarted = true;
+
         if (flags & RefreshFlags.RESET_OFFSET)
             Global.offsetController.resetOffset();
 
@@ -260,7 +239,6 @@ TrackerController.prototype = {
 
         this._setQueryStatus(true);
         Global.documentManager.clear();
-        this._offsetController.resetItemCount();
 
         this._performCurrentQuery();
     },
@@ -284,6 +262,13 @@ TrackerController.prototype = {
         if (this._currentQuery.activeSource &&
             this._currentQuery.activeSource.id == 'all')
             this._refreshInternal(RefreshFlags.NONE);
+    },
+
+    start: function() {
+        if (this._isStarted)
+            return;
+
+        this._refreshInternal(RefreshFlags.NONE);
     }
 };
 Signals.addSignalMethods(TrackerController.prototype);
