@@ -111,17 +111,14 @@ function View() {
 
 View.prototype = {
     _init: function() {
-        this._selectedURNs = null;
-        this._updateSelectionId = 0;
-
         this.widget = new Gd.MainView();
 
         this.widget.connect('item-activated',
                             Lang.bind(this, this._onItemActivated));
         this.widget.connect('selection-mode-request',
                             Lang.bind(this, this._onSelectionModeRequest));
-        this.widget.connect('notify::view-type',
-                            Lang.bind(this, this._onViewTypeChanged));
+        this.widget.connect('view-selection-changed',
+                            Lang.bind(this, this._onViewSelectionChanged));
 
         // connect to settings change for list/grid view
         this._viewSettingsId =
@@ -138,6 +135,8 @@ View.prototype = {
         this._queryId =
             Global.trackerController.connect('query-status-changed',
                                              Lang.bind(this, this._onQueryStatusChanged));
+        // ensure the tracker controller is started
+        Global.trackerController.start();
 
         // this will create the model if we're done querying
         this._onQueryStatusChanged();
@@ -147,6 +146,9 @@ View.prototype = {
     _updateTypeForSettings: function() {
         let viewType = Global.settings.get_enum('view-as');
         this.widget.set_view_type(viewType);
+
+        if (viewType == Gd.MainViewType.LIST)
+            this._addListRenderers();
     },
 
     _addListRenderers: function() {
@@ -220,23 +222,6 @@ View.prototype = {
             }));
     },
 
-    _onViewTypeChanged: function() {
-        if (this.widget.get_view_type() == Gd.MainViewType.LIST)
-            this._addListRenderers();
-
-        // setup selections view => controller
-        let generic = this.widget.get_generic_view();
-        generic.connect('view-selection-changed', Lang.bind(this, this._onSelectionChanged));
-
-        Global.selectionController.freezeSelection(false);
-
-        generic.connect('destroy', Lang.bind(this,
-            function() {
-                // save selection when the view is destroyed
-                Global.selectionController.freezeSelection(true);
-            }));
-    },
-
     _onSelectionModeRequest: function() {
         Global.selectionController.setSelectionMode(true);
     },
@@ -268,7 +253,8 @@ View.prototype = {
     },
 
     _updateSelection: function() {
-        let selected = Global.selectionController.getSelection().slice(0);
+        let selected = Global.selectionController.getSelection();
+        let newSelection = [];
 
         if (!selected.length)
             return;
@@ -282,7 +268,7 @@ View.prototype = {
 
                 if (idIndex != -1) {
                     this._treeModel.set_value(iter, Gd.MainColumns.SELECTED, true);
-                    selected.splice(idIndex, 1);
+                    newSelection.push(id);
 
                     if (first) {
                         generic.scroll_to_path(path);
@@ -290,11 +276,13 @@ View.prototype = {
                     }
                 }
 
-                if (selected.length == 0)
+                if (newSelection.length == selected.length)
                     return true;
 
                 return false;
             }));
+
+        Global.selectionController.setSelection(newSelection);
     },
 
     _onSelectionModeChanged: function() {
@@ -302,7 +290,7 @@ View.prototype = {
         this.widget.set_selection_mode(selectionMode);
     },
 
-    _onSelectionChanged: function() {
+    _onViewSelectionChanged: function() {
         // update the selection on the controller when the view signals a change
         let selectedURNs = Utils.getURNsFromPaths(this.widget.get_selection(),
                                                   this._treeModel);
